@@ -1,6 +1,6 @@
 //
 //	srecord - manipulate eprom load files
-//	Copyright (C) 2000, 2002, 2003 Peter Miller;
+//	Copyright (C) 2000, 2002, 2003, 2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,10 @@
   * The srec_input_file_guess function is used to open a file of an
   * unknown type.  It attempts all of the know formats one after the
   * other.
+  *
+  * @param filename
+  *     The name of the file to be opened.
   */
-srec_input *srec_input_file_guess(const char *);
+srec_input *srec_input_file_guess(const char *filename);
 
 #endif // INCLUDE_SREC_INPUT_FILE_GUESS_H
