@@ -28,18 +28,49 @@
 #include <crc16.h>
 #include <srec/memory/walker.h>
 
-class srec_memory_walker_crc16: public srec_memory_walker
+/**
+  * The srec_memory_walker_crc16 class is used to represent the parse
+  * state of a memory walker which calculates a running CRC16 checksum.
+  */
+class srec_memory_walker_crc16:
+    public srec_memory_walker
 {
 public:
-	virtual ~srec_memory_walker_crc16();
-	srec_memory_walker_crc16();
-	void observe(unsigned long, const void *, int);
-	unsigned get();
+    /**
+      * The destructror.
+      */
+    virtual ~srec_memory_walker_crc16();
+
+    /**
+      * The default constructor.
+      */
+    srec_memory_walker_crc16();
+
+    // See base class for documentation.
+    void observe(unsigned long, const void *, int);
+
+    /**
+      * The get method is used to get the CRC16 checksum once all memory
+      * chunks have been processed by calls to our observe method.
+      */
+    unsigned get() const;
 
 private:
-	crc16 checksum;
-	srec_memory_walker_crc16(const srec_memory_walker_crc16 &);
-	srec_memory_walker_crc16 &operator=(const srec_memory_walker_crc16 &);
+    /**
+      * The checksum instance variable is used to remember the running
+      * state of the CRC16 checksum calculation.
+      */
+    crc16 checksum;
+
+    /**
+      * The copy constructor.  No not use.
+      */
+    srec_memory_walker_crc16(const srec_memory_walker_crc16 &);
+
+    /**
+      * The assignment operator.  No not use.
+      */
+    srec_memory_walker_crc16 &operator=(const srec_memory_walker_crc16 &);
 };
 
 #endif // INCLUDE_SREC_MEMORY_WALKER_CRC16_H
